HARD_IGNORE_PATTERNS = [
    ".git",
    ".venv",
    "__pycache__",
    ".DS_Store",
    ".ruff_cache",
    ".pytest_cache",
    ".mypy_cache",
    ".cache",
    "build",
    "dist",
    "*.egg-info",
    ".eggs",
    "htmlcov",
    ".coverage",
    "*.swp",
    "*~",
    ".idea",
    ".vscode",
]
